"""Base class for Testing."""
import logging
import os
import tempfile
import unittest

from zaza import model


class BaseTestCase(unittest.TestCase):
    """Base class for graylog functional testing."""

    @classmethod
    def setUpClass(cls):
        """Configure the test's environment.

        - Get the CA from easyrsa (when available) and write it on disk.
        """
        if cls.get_api_protocol() == "https":
            rel_id = model.get_relation_id(
                "graylog", "easyrsa", remote_interface_name="client"
            )
            easyrsa_unit = model.get_units("easyrsa")[0]
            cmd = "relation-get -r client:{} ca {}".format(
                rel_id, easyrsa_unit.entity_id
            )
            logging.info(cmd)
            result = model.run_on_unit(easyrsa_unit.entity_id, cmd)

            with tempfile.NamedTemporaryFile(mode="w", delete=False) as f:
                f.write(result["Stdout"])
                f.flush()
                cls.ca_path = f.name
        else:
            cls.ca_path = None

    @classmethod
    def tearDownClass(cls):
        """Remove the CA file that was written to disk during the setUp."""
        if cls.ca_path:
            os.remove(cls.ca_path)

    @classmethod
    def get_api_protocol(cls):  # noqa: D102
        if model.get_relation_id("graylog", "easyrsa"):
            return "https"
        else:
            return "http"
