"""Test helper functions."""
import unittest
from unittest import mock

from charms.layer.graylog import (
    get_api_port,
    get_api_url,
    validate_api_uri,
)


class TestLibraryUtils(unittest.TestCase):
    """Test lib.charms.layer.graylog utils."""

    @mock.patch("charms.layer.graylog.utils.get_flags")
    @mock.patch("charms.layer.graylog.utils.is_v2")
    def test_api(self, mock_v2, mock_get_flags):
        """Validate the api port/url match what we expect for v2 and v3."""
        mock_v2.return_value = True
        self.assertEqual(get_api_port(), "9001")
        mock_get_flags.return_value = []
        self.assertEqual(get_api_url(), "http://127.0.0.1:9001/api/")

        mock_get_flags.reset_mock()
        mock_get_flags.return_value = ["graylog.certificates.configured"]
        self.assertEqual(get_api_url(), "https://127.0.0.1:9001/api/")

        mock_v2.return_value = False
        self.assertEqual(get_api_port(), "9000")
        mock_get_flags.reset_mock()
        mock_get_flags.return_value = []
        self.assertEqual(get_api_url(), "http://127.0.0.1:9000/api/")

        mock_get_flags.reset_mock()
        mock_get_flags.return_value = ["graylog.certificates.configured"]
        self.assertEqual(get_api_url(), "https://127.0.0.1:9000/api/")

    @mock.patch("charms.layer.graylog.utils.is_v2")
    def test_validate_api_url(self, mock_v2):
        """Validate the URI suffix is valid for v2 and v3."""
        mock_v2.return_value = True
        self.assertEqual(validate_api_uri("foo"), "foo/api/")
        self.assertEqual(validate_api_uri("foo/"), "foo/api/")
        self.assertEqual(validate_api_uri("foo/api"), "foo/api/")

        mock_v2.return_value = False
        self.assertEqual(validate_api_uri("foo"), "foo/")
        self.assertEqual(validate_api_uri("foo/"), "foo/")
        self.assertEqual(validate_api_uri("foo/api/"), "foo/")
